deviceaccess

package
v0.3.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 1, 2026 License: MIT, MIT Imports: 2 Imported by: 0

Documentation

Overview

Package deviceaccess provides the Chrome DevTools Protocol commands, types, and events for the DeviceAccess domain.

Generated by the cdproto-gen command.

Index

Constants

const (
	CommandEnable       = "DeviceAccess.enable"
	CommandDisable      = "DeviceAccess.disable"
	CommandSelectPrompt = "DeviceAccess.selectPrompt"
	CommandCancelPrompt = "DeviceAccess.cancelPrompt"
)

Command names.

Variables

This section is empty.

Functions

This section is empty.

Types

type CancelPromptParams

type CancelPromptParams struct {
	ID RequestID `json:"id"`
}

CancelPromptParams cancel a prompt in response to a DeviceAccess.deviceRequestPrompted event.

func CancelPrompt

func CancelPrompt(id RequestID) *CancelPromptParams

CancelPrompt cancel a prompt in response to a DeviceAccess.deviceRequestPrompted event.

See: https://chromedevtools.github.io/devtools-protocol/tot/DeviceAccess#method-cancelPrompt

parameters:

id

func (*CancelPromptParams) Do

func (p *CancelPromptParams) Do(ctx context.Context) (err error)

Do executes DeviceAccess.cancelPrompt against the provided context.

type DeviceID

type DeviceID string

DeviceID a device id.

See: https://chromedevtools.github.io/devtools-protocol/tot/DeviceAccess#type-DeviceId

func (DeviceID) String

func (t DeviceID) String() string

String returns the DeviceID as string value.

type DisableParams

type DisableParams struct{}

DisableParams disable events in this domain.

func Disable

func Disable() *DisableParams

Disable disable events in this domain.

See: https://chromedevtools.github.io/devtools-protocol/tot/DeviceAccess#method-disable

func (*DisableParams) Do

func (p *DisableParams) Do(ctx context.Context) (err error)

Do executes DeviceAccess.disable against the provided context.

type EnableParams

type EnableParams struct{}

EnableParams enable events in this domain.

func (*EnableParams) Do

func (p *EnableParams) Do(ctx context.Context) (err error)

Do executes DeviceAccess.enable against the provided context.

type EventDeviceRequestPrompted

type EventDeviceRequestPrompted struct {
	ID      RequestID       `json:"id"`
	Devices []*PromptDevice `json:"devices"`
}

EventDeviceRequestPrompted a device request opened a user prompt to select a device. Respond with the selectPrompt or cancelPrompt command.

See: https://chromedevtools.github.io/devtools-protocol/tot/DeviceAccess#event-deviceRequestPrompted

type PromptDevice

type PromptDevice struct {
	ID   DeviceID `json:"id"`
	Name string   `json:"name"` // Display name as it appears in a device request user prompt.
}

PromptDevice device information displayed in a user prompt to select a device.

See: https://chromedevtools.github.io/devtools-protocol/tot/DeviceAccess#type-PromptDevice

type RequestID

type RequestID string

RequestID device request id.

See: https://chromedevtools.github.io/devtools-protocol/tot/DeviceAccess#type-RequestId

func (RequestID) String

func (t RequestID) String() string

String returns the RequestID as string value.

type SelectPromptParams

type SelectPromptParams struct {
	ID       RequestID `json:"id"`
	DeviceID DeviceID  `json:"deviceId"`
}

SelectPromptParams select a device in response to a DeviceAccess.deviceRequestPrompted event.

func SelectPrompt

func SelectPrompt(id RequestID, deviceID DeviceID) *SelectPromptParams

SelectPrompt select a device in response to a DeviceAccess.deviceRequestPrompted event.

See: https://chromedevtools.github.io/devtools-protocol/tot/DeviceAccess#method-selectPrompt

parameters:

id
deviceID

func (*SelectPromptParams) Do

func (p *SelectPromptParams) Do(ctx context.Context) (err error)

Do executes DeviceAccess.selectPrompt against the provided context.

Jump to